@@ -9,8 +9,8 @@ class WriteL1Data(WriteL1Frame):
         self, header: fits.Header, stokes: Literal["I", "Q", "U", "V"]
     ) -> fits.Header:
         header["DAAXES"] = 2
-        header["DEAXES"] = 3
-        header["DNAXIS"] = 5
+        header["DEAXES"] = 1
+        header["DNAXIS"] = 3
         header["FRAMEWAV"] = 123.45
         header["LEVEL"] = 1
         header["WAVEMAX"] = 124
@@ -18,33 +18,21 @@ class WriteL1Data(WriteL1Frame):
         header["WAVEREF"] = "Air"
         header["WAVEUNIT"] = -9
         header["DINDEX3"] = 3
-        header["DINDEX4"] = 2
-        header["DINDEX5"] = 1
         header["DNAXIS1"] = header["NAXIS1"]
         header["DNAXIS2"] = header["NAXIS2"]
         header["DNAXIS3"] = 10
-        header["DNAXIS4"] = 1
-        header["DNAXIS5"] = 4
-        header["DPNAME1"] = ""
-        header["DPNAME2"] = ""
-        header["DPNAME3"] = ""
-        header["DPNAME4"] = ""
-        header["DPNAME5"] = ""
+        header["DPNAME1"] = "spatial x"
+        header["DPNAME2"] = "spatial y"
+        header["DPNAME3"] = "frame number"
         header["DTYPE1"] = "SPATIAL"
         header["DTYPE2"] = "SPATIAL"
         header["DTYPE3"] = "TEMPORAL"
-        header["DTYPE4"] = "SPECTRAL"
-        header["DTYPE5"] = "STOKES"
-        header["DUNIT1"] = ""
-        header["DUNIT2"] = ""
-        header["DUNIT3"] = ""
-        header["DUNIT4"] = ""
-        header["DUNIT5"] = ""
-        header["DWNAME1"] = ""
-        header["DWNAME2"] = ""
-        header["DWNAME3"] = ""
-        header["DWNAME4"] = ""
-        header["DWNAME5"] = ""
+        header["DUNIT1"] = "arcsec"
+        header["DUNIT2"] = "arcsec"
+        header["DUNIT3"] = "s"
+        header["DWNAME1"] = "helioprojective longitude"
+        header["DWNAME2"] = "helioprojective latitude"
+        header["DWNAME3"] = "time"
         header["CALVERS"] = ""
         header["CAL_URL"] = ""
         header["HEADVERS"] = ""
